pub struct EntityFireFreezeState {
pub(super) remaining_fire_ticks: i32,
pub(super) ticks_frozen: i32,
pub(super) is_in_powder_snow: bool,
pub(super) was_in_powder_snow: bool,
pub(super) has_visual_fire: bool,
}Expand description
Vanilla base fire and freezing state.
Fields
remaining_fire_ticks: i32ticks_frozen: i32is_in_powder_snow: boolwas_in_powder_snow: boolhas_visual_fire: boolImplementations
Sourceimpl EntityFireFreezeState
impl EntityFireFreezeState
Sourcepub const fn from_parts(
remaining_fire_ticks: i32,
ticks_frozen: i32,
is_in_powder_snow: bool,
was_in_powder_snow: bool,
has_visual_fire: bool,
) -> Self
pub const fn from_parts( remaining_fire_ticks: i32, ticks_frozen: i32, is_in_powder_snow: bool, was_in_powder_snow: bool, has_visual_fire: bool, ) -> Self
Creates fire/freeze state restored from persistent data.
Sourcepub const fn remaining_fire_ticks(self) -> i32
pub const fn remaining_fire_ticks(self) -> i32
Returns vanilla remainingFireTicks.
Sourcepub const fn ticks_frozen(self) -> i32
pub const fn ticks_frozen(self) -> i32
Returns synchronized vanilla TicksFrozen.
Sourcepub const fn is_in_powder_snow(self) -> bool
pub const fn is_in_powder_snow(self) -> bool
Returns whether this entity touched powder snow during the current tick.
Sourcepub const fn was_in_powder_snow(self) -> bool
pub const fn was_in_powder_snow(self) -> bool
Returns whether this entity touched powder snow during the previous tick.
Sourcepub const fn has_visual_fire(self) -> bool
pub const fn has_visual_fire(self) -> bool
Returns vanilla hasVisualFire.
Sourcepub const fn is_freezing(self) -> bool
pub const fn is_freezing(self) -> bool
Returns whether the entity has any frozen ticks.
Sourcepub const fn is_fully_frozen(self, ticks_required_to_freeze: i32) -> bool
pub const fn is_fully_frozen(self, ticks_required_to_freeze: i32) -> bool
Returns whether the entity has reached vanilla full-freeze duration.